==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/apps/v1/ReplicaSetList.scala <==
package io.k8s.api.apps.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** ReplicaSetList is a collection of ReplicaSets. */
final case class ReplicaSetList(
  items : Seq[io.k8s.api.apps.v1.ReplicaSet],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("apps", "ReplicaSetList", "v1")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.apps.v1.ReplicaSet]) : ReplicaSetList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.apps.v1.ReplicaSet*) : ReplicaSetList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.apps.v1.ReplicaSet] => Seq[io.k8s.api.apps.v1.ReplicaSet]) : ReplicaSetList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : ReplicaSetList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : ReplicaSetList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = ReplicaSetList.encoder[T].apply(this)
}

object ReplicaSetList {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.apps.v1.ReplicaSetList, T] = new Encoder[io.k8s.api.apps.v1.ReplicaSetList, T] {
        def apply(o: io.k8s.api.apps.v1.ReplicaSetList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ReplicaSetList] = new Decoder[T, ReplicaSetList] {
      def apply(t: T): Either[String, ReplicaSetList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.apps.v1.ReplicaSet]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield ReplicaSetList (
          items = items,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_2.12-0.5.0-sources.jar: io/k8s/api/apps/v1/ReplicaSetList.scala <==
package io.k8s.api.apps.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** ReplicaSetList is a collection of ReplicaSets. */
final case class ReplicaSetList(
  items : Seq[io.k8s.api.apps.v1.ReplicaSet],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("apps", "ReplicaSetList", "v1")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.apps.v1.ReplicaSet]) : ReplicaSetList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.apps.v1.ReplicaSet*) : ReplicaSetList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.apps.v1.ReplicaSet] => Seq[io.k8s.api.apps.v1.ReplicaSet]) : ReplicaSetList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : ReplicaSetList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : ReplicaSetList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = ReplicaSetList.encoder.apply(this)
}

object ReplicaSetList {

    implicit val encoder : Encoder[io.k8s.api.apps.v1.ReplicaSetList] = new Encoder[io.k8s.api.apps.v1.ReplicaSetList] {
        def apply[T : Builder](o: io.k8s.api.apps.v1.ReplicaSetList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[ReplicaSetList] = new Decoder[ReplicaSetList] {
      def apply[T : Reader](t: T): Either[String, ReplicaSetList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.apps.v1.ReplicaSet]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield ReplicaSetList (
          items = items,
          metadata = metadata
        )
    }
}
